pub trait InternalIteratorRec: InternalIterator<Item = Self::Item> {
type Item;
// Required method
fn try_for_each_rec<R, F>(self, f: &mut F) -> ControlFlow<R>
where F: FnMut(<Self as InternalIteratorRec>::Item) -> ControlFlow<R>;
}Expand description
An “internal” iterator trait that supports recursively jumping between types.
Generally this isn’t implemented manually, you probably want to use the adhoc_internal_iterator_rec! macro within a function body to generate the appropriate code.
Required Associated Types
Required Methods
fn try_for_each_rec<R, F>(self, f: &mut F) -> ControlFlow<R>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.